<?php

add_action("manage_posts_custom_column", "tw_posttype_custom_columns");
function tw_posttype_custom_columns($column) {
    global $post;
    switch ($column) {
        case "portfolio_cat":
            echo get_the_term_list($post->ID, 'portfolio_cat', '', ', ', '');
            break;
        case "portfolio_tag":
            echo get_the_term_list($post->ID, 'portfolio_tag', '', ', ', '');
            break;
        case "slider_cat":
            echo get_the_term_list($post->ID, 'slider_cat', '', ', ', '');
            break;
    }
}

/* * *********************** */
/* Custom post type: Portfolio */
/* * *********************** */

add_action('init', 'tw_portfolio_register');
function tw_portfolio_register() {
    $slug = tw_option('translate_portfolio') ? tw_option('translate_portfolio') : 'portfolio';
    $labels = array(
        'name' => $slug,
        'singular_name' => $slug,
        'add_new' => __('Add New', 'themewaves'),
        'add_new_item' => __('Add New Portfolio', 'themewaves'),
        'edit_item' => __('Edit Portfolio', 'themewaves'),
        'new_item' => __('New Portfolio', 'themewaves'),
        'all_items' => __('All Portfolios', 'themewaves'),
        'view_item' => __('View Portfolio', 'themewaves'),
        'search_items' => __('Search Portfolios', 'themewaves'),
        'not_found' =>  __('No Portfolio found', 'themewaves'),
        'not_found_in_trash' => __('No Portfolio found in Trash', 'themewaves'),
        'menu_name' => __('Portfolios', 'themewaves')
    );    
    $args = array(
        'labels' => $labels,
        'public' => true,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => false,
        'show_ui' => true,
        'hierarchical' => false,

        'menu_icon' => THEME_DIR . '/framework/images/portfolio.png',
        'rewrite' => array( 'slug' => $slug),
        'supports' => array('title', 'editor','page-attributes','thumbnail','custom-fields','revisions')
    );
    register_post_type('portfolio', $args);
    register_taxonomy("portfolio_cat", array("portfolio"), array("hierarchical" => true, "label" => __("Categories", "themewaves"), "singular_label" => __("Portfolio Category", "themewaves"), 'rewrite' => array( 'slug' => $slug.'_category')));
    register_taxonomy("portfolio_tag", array("portfolio"), array("hierarchical" => true, "label" => __("Tags", "themewaves"), "singular_label" => __("Portfolio Tag", "themewaves"), 'rewrite' => array( 'slug' => $slug.'_tag')));
    flush_rewrite_rules();
}


add_filter('manage_edit-portfolio_columns', 'tw_portfolio_edit_columns');
function tw_portfolio_edit_columns($columns){	
    $newcolumns = array(
        "cb" => "<input type=\"checkbox\" />",
        "title" => __("Portfolio Title", "waves"),
        "portfolio_cat" => __("Categories", "waves"),
        "portfolio_tag" => __("Tags", "waves"),
    );
    $columns= array_merge($newcolumns, $columns);
    return $columns;
}




/* * *********************** */
/* Custom post type: Slider */
/* * *********************** */

//add_action('init', 'tw_slider_register');
function tw_slider_register() {
    $slug = 'waves-slider';
    $labels = array(
        'name' => $slug,
        'singular_name' => $slug,
        'add_new' => __('Add New', 'themewaves'),
        'add_new_item' => __('Add New One Page Header', 'themewaves'),
        'edit_item' => __('Edit One Page Header', 'themewaves'),
        'new_item' => __('New One Page Header', 'themewaves'),
        'all_items' => __('All One Page Header', 'themewaves'),
        'view_item' => __('View One Page Header', 'themewaves'),
        'search_items' => __('Search One Page Header', 'themewaves'),
        'not_found' =>  __('No Header found', 'themewaves'),
        'not_found_in_trash' => __('No Slider found in Trash', 'themewaves'),
        'menu_name' => __('One Page Header', 'themewaves')
    );    
    $args = array(
        'labels' => $labels,
        'public' => false,
        'has_archive' => false,
        'publicly_queryable' => true,
        'exclude_from_search' => false,
        'show_ui' => true,
        'hierarchical' => false,

        'menu_icon' => THEME_DIR . '/framework/images/portfolio.png',
        'rewrite' => array( 'slug' => $slug),
        'supports' => array('title', 'editor','page-attributes','thumbnail','revisions')
    );
    register_post_type('slider', $args);
    register_taxonomy("slider_cat", array("slider"), array("hierarchical" => true, "label" => __("Categories", "themewaves"), "singular_label" => __("Slider Category", "themewaves"), 'rewrite' => array( 'slug' => $slug.'_category')));
    flush_rewrite_rules();
}


//add_filter('manage_edit-slider_columns', 'tw_slider_edit_columns');
function tw_slider_edit_columns($columns){	
    $newcolumns = array(
        "cb" => "<input type=\"checkbox\" />",
        "title" => __("Slider Title", "waves"),
        "slider_cat" => __("Categories", "waves"),
    );
    $columns= array_merge($newcolumns, $columns);
    return $columns;
}